@@ -1,10 +1,12 @@
 /*
   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
-  SPDX-License-Identifier: GPL-2.0-only
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "selectthunderbirdprofiledialogtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../selectthunderbirdprofilewidget.h"
 
 #include <QDialogButtonBox>
@@ -18,9 +20,9 @@ SelectThunderbirdProfileDialogTest::SelectThunderbirdProfileDialogTest(QObject *
 void SelectThunderbirdProfileDialogTest::shouldHaveDefaultValue()
 {
     MailImporter::SelectThunderbirdProfileDialog dlg;
-    auto widget = dlg.findChild<MailImporter::SelectThunderbirdProfileWidget *>(QStringLiteral("selectprofile"));
+    auto widget = dlg.findChild<MailImporter::SelectThunderbirdProfileWidget *>(u"selectprofile"_s);
     QVERIFY(widget);
-    auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonBox"));
+    auto buttonBox = dlg.findChild<QDialogButtonBox *>(u"buttonBox"_s);
     QVERIFY(buttonBox);
 }
 
